@@ -51,6 +51,8 @@ def test_get_spot_attributes_as_df():
                             'ident',
                             'infill_criterion',
                             'k',
+                            'kernel',
+                            'kernel_params',
                             'log_level',
                             'lower',
                             'max_surrogate_points',
@@ -71,6 +73,7 @@ def test_get_spot_attributes_as_df():
                             'progress_file',
                             'red_dim',
                             'rng',
+                            'selection_method',
                             'show_models',
                             'show_progress',
                             'spot_writer',
